// Copyright 2022 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package configuration

import "path"

// deprecated
type PathValueInterface interface {
	String() string
	Dir() string
	Ext() string
	Base() string
}

// PathValuer is an interface for path values
type PathValuer interface {
	String() string
	Dir() string
	Ext() string
	Base() string
	IsAbs() bool
	Join(parts ...string) PathValue
	Clean() PathValue
}

type PathValue string

func (p PathValue) Dir() string {
	return path.Dir(string(p))
}

func (p PathValue) Ext() string {
	return path.Ext(string(p))
}

func (p PathValue) String() string {
	return string(p)
}

func (p PathValue) Base() string {
	return path.Base(string(p))
}

func (p PathValue) IsAbs() bool {
	return path.IsAbs(string(p))
}

func (p PathValue) Clean() PathValue {
	return PathValue(path.Clean(string(p)))
}

func (p PathValue) Join(parts ...string) PathValue {
	return PathValue(path.Join(append([]string{string(p)}, parts...)...))
}
